@@ -273,6 +273,8 @@ class resultFile:
 			function = bf.gaussian
 		try:
 			fitres = Nab.bf.curve_fit(function, bin_edges[:-1]+width/2, histogram, p0=p0, sigma=sigma, absolute_sigma = absolute_sigma, check_finite = check_finite, bounds=bounds, method=method, jac=jac)
+		except:
+			fitres = [None, None]
 		if fitres[0] is not None and fitres[1] is not None:
 			popt, pcov = fitres
 			if popt is not None and pcov is not None:
